./Doxyfile.in         This file describes the settings to be used by the 
                      documentation system

./AMCL.dox            Main page of the documentation.

To generate the documentation type: make doc

This will generate the directories

./html    html output

./latex   latex source files. The pdf can be generated by
          typing: make. The output is refman.pdf.

./xml     XML output


